@@ -144,10 +144,10 @@ class AttributeCache:
         await self._async_value()
         return response
 
-    async def close_value(self):
+    async def close_value(self, params=None):
         if self.attribute.close_command is None:
             raise RoborockException(f"{self.attribute.attribute} have no close command")
-        response = await self.api._send_command(self.attribute.close_command)
+        response = await self.api._send_command(self.attribute.close_command, params)
         await self._async_value()
         return response
 
